<?php

$cPickPath = get_template_directory() . '/inc/alpha-color-picker/';
include_once ABSPATH . 'wp-includes/class-wp-customize-control.php';
require_once($cPickPath . 'alpha-color-picker.php');


//Customize panel

function bny_sanitize_checkbox($checked) {
	return ((isset($checked) && true == $checked) ? true : false);
}

function bny_customize_register($wp_customize) {

	// Sections //
	$wp_customize->add_section('bonyo_options',	array(
		'title'             => __('Options', 'bonyo'),
		'priority'          => 40,
		'description'       => __('Changes to these items will not be reflected in the preview.', 'bonyo'),
	));

	$wp_customize->add_section('bonyo_sizes', array(
		'title'     => __('Sizes', 'bonyo'),
		'priority'  => 50, 
	));

	$wp_customize->get_section('colors')->description = __('Preview works only immediately after changing the value. Ignore it even if it seems that the changed value returned to its original state. The changed values will not be reflected until you log off the admin panel.', 'bonyo');


	//Static sidebar
	$wp_customize->add_setting('ck_sidebar', array(
		'default'			=> false,
		'sanitize_callback'	=> 'bny_sanitize_checkbox',
	));
	$wp_customize->add_control(new WP_Customize_Control($wp_customize, 'ck_sidebar', array(
		'label'				=> __('Dinamic/Static sidebar', 'bonyo'),
		'description'       => __('<p>Checked is static sidebar.<br />Unchecked is dynamic sidebar.</p><p>If it is static, the sidebar is output to the template file.<br />It is fast, but the same sidebar code is displayed every time. <br />The sidebar template is created or updated when logging off the administration panel.</p>', 'bonyo'),
		'section'			=> 'bonyo_options',
		'priority'			=> 10,
		'type'				=> 'checkbox',
	)));

	//Lazy loading
	$wp_customize->add_setting('ck_lazy', array(
		'default'			=> false,
		'sanitize_callback'	=> 'bny_sanitize_checkbox',
	));
	$wp_customize->add_control(new WP_Customize_Control($wp_customize, 'ck_lazy', array(
		'label'				=> __('Lazy loading images / Normal loading images', 'bonyo'),
		'description'       => __('<p>Checked is lazy-loading images.<br />Uncheck is normal loading images.</p><p>Lazy-loading images is faster than normal-loading.<br />In Bonyo, consideration is given so that delayed reading of images does not adversely affect SEO.</p>', 'bonyo'),
		'section'			=> 'bonyo_options',
		'priority'			=> 20,
		'type'				=> 'checkbox',
	)));


	$wp_customize->add_setting('ck_bg', array(
		'default'           => true,
		'sanitize_callback' => 'bny_sanitize_checkbox',
	));
	$wp_customize->add_control(new WP_Customize_Control($wp_customize, 'ck_bg', array(
		'label'             => __('Enable/Disable background image', 'bonyo'),
		'description'       => __('<p>Please check if you want to display the background image of pages. If not checked, fill with solid color. </p>', 'bonyo'),
		'section'           => 'bonyo_options',
		'priority'          => 30,
		'type'              => 'checkbox',
	)));



	// Background image //
	$wp_customize->add_setting('page_bg_image', array(
		'default'           => get_template_directory_uri() . '/images/bonyo-bg.png',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'page_bg_image', array(
		'label'             => __('Please choose a background image of pages.', 'bonyo'),
		'section'           => 'bonyo_options',
		'priority'          => 31,
	)));


	// Colors //

	//Text color
	$wp_customize->add_setting('page_text_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'page_text_color', array(
		'section'           => 'colors',
		'label'             => __('Page Text color', 'bonyo'),
		'priority'          => 31,
	)));

	//Page background color 
	$wp_customize->add_setting('page_bg_color', array(
		'default'           => '#eee',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'page_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Page background color', 'bonyo'),
		'priority'          => 32,
	)));

	//Site title color
	$wp_customize->add_setting('site_title_color', array(
		'default'           => '#4888ff',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'site_title_color', array(
		'section'           => 'colors',
		'label'             => __('Site title color', 'bonyo'),
		'priority'          => 33,
	)));

	//Page link color (Link)
	$wp_customize->add_setting('page_link_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'page_link_color', array(
		'section'           => 'colors',
		'label'             => __('Page Link color (Link)', 'bonyo'),
		'priority'          => 34,
	)));

	//Page link color (Visited)
	$wp_customize->add_setting('page_link_color_visited', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'page_link_color_visited', array(
		'section'           => 'colors',
		'label'             => __('Page link color (Visited)', 'bonyo'),
		'priority'          => 35,
	)));

	//Page link color (Hover)
	$wp_customize->add_setting('page_link_color_hover', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'page_link_color_hover', array(
		'section'           => 'colors',
		'label'             => __('Page link color (Hover)', 'bonyo'),
		'priority'          => 36,
	)));

	//Page link color (Active)
	$wp_customize->add_setting('page_link_color_active', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'page_link_color_active', array(
		'section'           => 'colors',
		'label'             => __('Page link color (Active)', 'bonyo'),
		'priority'          => 37,
	)));

	//Article back ground color
	$wp_customize->add_setting('article_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.1)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'article_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Article back ground color', 'bonyo'),
		'priority'          => 38,
	)));

	//Article title color
	$wp_customize->add_setting('article_title_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'article_title_color', array(
		'section'           => 'colors',
		'label'             => __('Article title color', 'bonyo'),
		'priority'          => 39,
	)));

	//Headline font color   h1,h2,h3,h4,h5,h6
	$wp_customize->add_setting('headline_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'headline_color', array(
		'section'           => 'colors',
		'label'             => __('Headline font color', 'bonyo'),
		'priority'          => 40,
	)));

	//Navigation menu icon font color (narrow screen)
	$wp_customize->add_setting('nav_icon_link_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'nav_icon_link_color', array(
		'section'           => 'colors',
		'label'             => __('Navigation menu icon font color (narrow screen)', 'bonyo'),
		'priority'          => 41,
	)));

	//Navigation menu icon background color (narrow screen)
	$wp_customize->add_setting('nav_icon_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.2)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'nav_icon_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Navigation menu icon background color (narrow screen)', 'bonyo'),
		'priority'          => 42,
	)));

	//Navigation menu link font color
	$wp_customize->add_setting('nav_link_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'nav_link_color', array(
		'section'           => 'colors',
		'label'             => __('Navigation menu link font color', 'bonyo'),
		'priority'          => 43,
	)));

	//Navigation menu background color
	$wp_customize->add_setting('nav_bar_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.1)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'nav_bar_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Navigation menu background color', 'bonyo'),
		'priority'          => 44,
	)));

	//Navigation menu item background color (Level 1)
	$wp_customize->add_setting('nav_lv1_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.1)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'nav_lv1_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Navigation menu item background color (Level 1)', 'bonyo'),
		'priority'          => 45,
	)));

	//Navigation menu item background color (Level 2)
	$wp_customize->add_setting('nav_lv2_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.1)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'nav_lv2_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Navigation menu item background color (Level 2)', 'bonyo'),
		'priority'          => 46,
	)));

	//Navigation menu item background color (Level 3)
	$wp_customize->add_setting('nav_lv3_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.1)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'nav_lv3_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Navigation menu item background color (Level 3)', 'bonyo'),
		'priority'          => 47,
	)));

	//Navigation item background color (Hover)
	$wp_customize->add_setting('nav_item_hover_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.4)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'nav_item_hover_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Navigation item background color (Hover)', 'bonyo'),
		'description'       => __('This item is not reflected in the preview.', 'bonyo'),
		'priority'          => 48,
	)));

	//Navigation sub menu background color
	$wp_customize->add_setting('nav_submenu_bg_color', array(
		'default'           => 'rgba(0, 0, 0, 0.3)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'nav_submenu_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Navigation sub menu background color', 'bonyo'),
		'priority'          => 49,
	)));

	//Navigation menu font color (Narrow screen)
	$wp_customize->add_setting('nav_narrow_link_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'nav_narrow_link_color', array(
		'section'           => 'colors',
		'label'             => __('Navigation menu font color (Narrow screen)', 'bonyo'),
		'priority'          => 50,
	)));

	//Navigation menu background color (Narrow screen)
	$wp_customize->add_setting('nav_narrow_bg_color', array(
		'default'           => '#f0f8ff',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'nav_narrow_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Navigation menu background color (Narrow screen)', 'bonyo'),
		'priority'          => 51,
	)));

	//Navigation menu item background color (Level 1) (Narrow screen)
	$wp_customize->add_setting('nav_narrow_lv1_bg_color', array(
		'default'           => 'rgba(40, 96, 144, 0.4)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'nav_narrow_lv1_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Navigation menu item background color (Level 1) (Narrow screen)', 'bonyo'),
		'priority'          => 52,
	)));

	//Navigation menu item background color (Level 2) (Narrow screen)
	$wp_customize->add_setting('nav_narrow_lv2_bg_color', array(
		'default'           => 'rgba(180, 220, 238, 0.6);',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'nav_narrow_lv2_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Navigation menu item background color (Level 2) (Narrow screen)', 'bonyo'),
		'priority'          => 53,
	)));

	//Navigation menu item background color (Level 3) (Narrow screen)
	$wp_customize->add_setting('nav_narrow_lv3_bg_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'nav_narrow_lv3_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Navigation menu item background color (Level 3) (Narrow screen)', 'bonyo'),
		'priority'          => 54,
	)));

	//Pagination item link color
	$wp_customize->add_setting('pagination_link_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'pagination_link_color', array(
		'section'           => 'colors',
		'label'             => __('Pagination item link color', 'bonyo'),
		'priority'          => 55,
	)));

	//Pagination item background color
	$wp_customize->add_setting('pagination_bg_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'pagination_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Pagination item background color', 'bonyo'),
		'priority'          => 56,
	)));

	//Pagination item background color (Hover)
	$wp_customize->add_setting('pagination_hover_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.2)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'pagination_hover_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Pagination item background color (Hover)', 'bonyo'),
		'priority'          => 57,
	)));

	//Button link font color
	$wp_customize->add_setting('button_link_color', array(
		'default'           => '#fff',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'button_link_color', array(
		'section'           => 'colors',
		'label'             => __('Button link font color', 'bonyo'),
		'priority'          => 58,
	)));

	//Button background color
	$wp_customize->add_setting('button_bg_color', array(
		'default'           => '#4888ff',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'button_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Button background color', 'bonyo'),
		'priority'          => 59,
	)));

	//Button background color (Hover)
	$wp_customize->add_setting('button_hover_bg_color', array(
		'default'           => '#4488cc',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'button_hover_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Button background color (Hover)', 'bonyo'),
		'priority'          => 60,
	)));

	//Search field font color
	$wp_customize->add_setting('search_field_font_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'search_field_font_color', array(
		'section'           => 'colors',
		'label'             => __('Search field font color', 'bonyo'),
		'priority'          => 61,
	)));

	//Search field background color
	$wp_customize->add_setting('search_field_bg_color', array(
		'default'           => 'rgba(255, 255, 255, 0.6)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'search_field_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Search field background color', 'bonyo'),
		'priority'          => 62,
	)));

	//Go to page top icon font color
	$wp_customize->add_setting('page_top_link_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'page_top_link_color', array(
		'section'           => 'colors',
		'label'             => __('Go to page top icon font color', 'bonyo'),
		'priority'          => 63,
	)));

	//Go to page top icon background color
	$wp_customize->add_setting('page_top_bg_color', array(
		'default'           => '#rgba(72, 136, 255, 0.1)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'page_top_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Go to page top icon background color', 'bonyo'),
		'priority'          => 64,
	)));

	//Go to page top icon background color (Hover)
	$wp_customize->add_setting('page_top_hover_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.2)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'page_top_hover_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Go to page top icon background color (Hover)', 'bonyo'),
		'priority'          => 65,
	)));

	//Sticky article background color
	$wp_customize->add_setting('sticky_article_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.1)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'sticky_article_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Sticky article background color', 'bonyo'),
		'priority'          => 66,
	)));

	//Archive text color
	$wp_customize->add_setting('archive_text_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'archive_text_color', array(
		'section'           => 'colors',
		'label'             => __('Archive text color', 'bonyo'),
		'priority'          => 67,
	)));

	//Archive background color
	$wp_customize->add_setting('archive_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.1)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'archive_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Archive background color', 'bonyo'),
		'priority'          => 68,
	)));

	//Widget link text color
	$wp_customize->add_setting('widget_link_text_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'widget_link_text_color', array(
		'section'           => 'colors',
		'label'             => __('Widget link text color', 'bonyo'),
		'priority'          => 69,
	)));

	//Widget link background color
	$wp_customize->add_setting('widget_link_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.1)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'widget_link_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Widget link background color', 'bonyo'),
		'priority'          => 70,
	)));

	//Widget link background color (Hover)
	$wp_customize->add_setting('widget_link_hover_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.2)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'widget_link_hover_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Widget link background color (Hover)', 'bonyo'),
		'priority'          => 71,
	)));

	//Widget calendar text color
	$wp_customize->add_setting('widget_calendar_text_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'widget_calendar_text_color', array(
		'section'           => 'colors',
		'label'             => __('Widget calendar text color', 'bonyo'),
		'priority'          => 72,
	)));

	//Widget calendar background color
	$wp_customize->add_setting('widget_calendar_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.1)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'widget_calendar_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Widget calendar background color', 'bonyo'),
		'priority'          => 73,
	)));

	//Widget tagcloud link color
	$wp_customize->add_setting('widget_tagcloud_link_color', array(
		'default'           => '#333',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'widget_tagcloud_link_color', array(
		'section'           => 'colors',
		'label'             => __('Widget tagcloud link color', 'bonyo'),
		'priority'          => 74,
	)));

	//Widget tagcloud background color
	$wp_customize->add_setting('widget_tagcloud_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.1)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'widget_tagcloud_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Widget tagcloud background color', 'bonyo'),
		'priority'          => 75,
	)));

	//Widget tagcloud background color (Hover)
	$wp_customize->add_setting('widget_tagcloud_hover_bg_color', array(
		'default'           => 'rgba(72, 136, 255, 0.2)',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'widget_tagcloud_hover_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Widget tagcloud background color (Hover)', 'bonyo'),
		'priority'          => 76,
	)));

	//Comments submit color
	$wp_customize->add_setting('comments_submit_color', array(
		'default'           => '#fff',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'comments_submit_color', array(
		'section'           => 'colors',
		'label'             => __('Comments submit color', 'bonyo'),
		'priority'          => 77,
	)));

	//Comments submit background color
	$wp_customize->add_setting('comments_submit_bg_color', array(
		'default'           => '#4888ff',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'comments_submit_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Comments submit background color', 'bonyo'),
		'priority'          => 78,
	)));

	//Comments submit background color (Hover)
	$wp_customize->add_setting('comments_submit_hover_bg_color', array(
		'default'           => '#3777ee',
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
	));
	$wp_customize->add_control(new Customize_Alpha_Color_Control($wp_customize, 'comments_submit_hover_bg_color', array(
		'section'           => 'colors',
		'label'             => __('Comments submit background color (Hover)', 'bonyo'),
		'priority'          => 79,
	)));
}
add_action('customize_register', 'bny_customize_register');



function bny_custom_preview() {
	$jsFile = get_template_directory_uri().'/inc/js/custom_preview.js';
	wp_enqueue_script('bny-preview', $jsFile, array('jquery','customize-preview' ), '', true);
}
add_action('customize_preview_init', 'bny_custom_preview');

?>
